Module Reference
===============

API Modules
----------

.. toctree::
   :maxdepth: 1

   systemair_api.api.systemair_api
   systemair_api.api.websocket_client

Authentication
-------------

.. toctree::
   :maxdepth: 1

   systemair_api.auth.authenticator

Models
-----

.. toctree::
   :maxdepth: 1

   systemair_api.models.ventilation_unit
   systemair_api.models.ventilation_data

Utils
----

.. toctree::
   :maxdepth: 1

   systemair_api.utils.constants
   systemair_api.utils.register_constants
   systemair_api.utils.exceptions